<?php

namespace Drupal\profile_tabs\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\profile\Entity\ProfileTypeInterface;
use Drupal\user\UserInterface;

/**
 * Provides the profile UI for users.
 */
class UserController extends ControllerBase {

  /**
   * Builds a page title for the given profile type.
   *
   * @param \Drupal\profile\Entity\ProfileTypeInterface $profile_type
   *   The profile type.
   *
   * @return string
   *   The page title.
   */
  public function title(UserInterface $user, ProfileTypeInterface $profile_type) {
    // return $profile_type->getDisplayLabel() ?: $profile_type->label();
    return $user->label();
  }

  /**
   * Builds a page to view the profile.
   *
   * @param \Drupal\user\UserInterface $user
   *   The user account.
   * @param \Drupal\profile\Entity\ProfileTypeInterface $profile_type
   *   The profile type.
   *
   * @return array
   *   The response.
   */
  public function singlePage(UserInterface $user, ProfileTypeInterface $profile_type) {
    /** @var \Drupal\profile\ProfileStorageInterface $profile_storage */
    $profile_storage = $this->entityTypeManager()->getStorage('profile');
    $profile = $profile_storage->loadByUser($user, $profile_type->id());

    /** @var \Drupal\profile\ProfileViewBuilder  $profile_view_builder */
    $profile_view_builder = $this->entityTypeManager()->getViewBuilder('profile');
    return $profile_view_builder->view($profile);
  }

  /**
   * Checks access for the single/multiple pages.
   *
   * @param \Drupal\user\UserInterface $user
   *   The user account.
   * @param \Drupal\profile\Entity\ProfileTypeInterface $profile_type
   *   The profile type.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function checkAccess(UserInterface $user, ProfileTypeInterface $profile_type, AccountInterface $account) {
    $user_access = $user->access('view', $account, TRUE);
    if (!$user_access->isAllowed()) {
      // The account does not have access to the user's canonical page
      // ("/user/{user}"), don't allow access to any sub-pages either.
      return $user_access;
    }

    /** @var \Drupal\profile\ProfileStorageInterface $profile_storage */
    $profile_storage = $this->entityTypeManager()->getStorage('profile');
    $profile = $profile_storage->loadByUser($user, $profile_type->id());
    if (!$profile) {
      // Profile does not exist thus no access.
      return AccessResult::forbidden();
    }

    $access_control_handler = $this->entityTypeManager()->getAccessControlHandler('profile');
    $operation = 'view';
    $result = $access_control_handler->access($profile, $operation, $account, TRUE);

    return $result;
  }

}
